# Version History

## 0.0.0.4

* Update depends nativelib==0.2.1.1
* Update depends pgcopylib==0.2.1.8
* Update depends pgpack==0.3.0.8

## 0.0.0.3

* Add wheels automake
* Change nativelib cimport to import

## 0.0.0.2

* Fix initialize compression_method from string
* Fix convert from native dump to pgpack/pgcopy

## 0.0.0.1

First version of the library dbhose_utils
